pitchtools.list_harmonic_diatonic_intervals_in_expr
===================================================

.. autofunction:: abjad.tools.pitchtools.list_harmonic_diatonic_intervals_in_expr.list_harmonic_diatonic_intervals_in_expr
